/****************************************************************************
** QgsRasterLayer meta object code from reading C++ file 'qgsrasterlayer.h'
**
** Created: Fri Nov 4 14:08:55 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "qgsrasterlayer.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsRasterLayer::className() const
{
    return "QgsRasterLayer";
}

QMetaObject *QgsRasterLayer::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsRasterLayer( "QgsRasterLayer", &QgsRasterLayer::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsRasterLayer::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsRasterLayer", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsRasterLayer::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsRasterLayer", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsRasterLayer::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QgsMapLayer::staticMetaObject();
    static const QUParameter param_slot_0[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_0 = {"inOverview", 1, param_slot_0 };
    static const QUParameter param_slot_1[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_1 = {"popupTransparencySliderMoved", 1, param_slot_1 };
    static const QUParameter param_slot_2[] = {
	{ 0, &static_QUType_ptr, "RasterPyramidList", QUParameter::In }
    };
    static const QUMethod slot_2 = {"buildPyramids", 1, param_slot_2 };
    static const QUParameter param_slot_3[] = {
	{ 0, &static_QUType_ptr, "RasterPyramidList", QUParameter::In },
	{ "theResamplingMethod", &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_3 = {"buildPyramids", 2, param_slot_3 };
    static const QUMethod slot_4 = {"showLayerProperties", 0, 0 };
    static const QUParameter param_slot_5[] = {
	{ "theBandNoInt", &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_5 = {"populateHistogram", 1, param_slot_5 };
    static const QUParameter param_slot_6[] = {
	{ "theBandNoInt", &static_QUType_int, 0, QUParameter::In },
	{ "theBinCountInt", &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_6 = {"populateHistogram", 2, param_slot_6 };
    static const QUParameter param_slot_7[] = {
	{ "theBandNoInt", &static_QUType_int, 0, QUParameter::In },
	{ "theBinCountInt", &static_QUType_int, 0, QUParameter::In },
	{ "theIgnoreOutOfRangeFlag", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_7 = {"populateHistogram", 3, param_slot_7 };
    static const QUParameter param_slot_8[] = {
	{ "theBandNoInt", &static_QUType_int, 0, QUParameter::In },
	{ "theBinCountInt", &static_QUType_int, 0, QUParameter::In },
	{ "theIgnoreOutOfRangeFlag", &static_QUType_bool, 0, QUParameter::In },
	{ "theThoroughBandScanFlag", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_8 = {"populateHistogram", 4, param_slot_8 };
    static const QUParameter param_slot_9[] = {
	{ 0, &static_QUType_ptr, "QgsColorTable", QUParameter::Out },
	{ "theBandNoInt", &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_9 = {"colorTable", 2, param_slot_9 };
    static const QMetaData slot_tbl[] = {
	{ "inOverview(bool)", &slot_0, QMetaData::Public },
	{ "popupTransparencySliderMoved(int)", &slot_1, QMetaData::Public },
	{ "buildPyramids(RasterPyramidList)", &slot_2, QMetaData::Public },
	{ "buildPyramids(RasterPyramidList,QString)", &slot_3, QMetaData::Public },
	{ "showLayerProperties()", &slot_4, QMetaData::Public },
	{ "populateHistogram(int)", &slot_5, QMetaData::Public },
	{ "populateHistogram(int,int)", &slot_6, QMetaData::Public },
	{ "populateHistogram(int,int,bool)", &slot_7, QMetaData::Public },
	{ "populateHistogram(int,int,bool,bool)", &slot_8, QMetaData::Public },
	{ "colorTable(int)", &slot_9, QMetaData::Public }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsRasterLayer", parentObject,
	slot_tbl, 10,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsRasterLayer.setMetaObject( metaObj );
    return metaObj;
}

void* QgsRasterLayer::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsRasterLayer" ) )
	return this;
    return QgsMapLayer::qt_cast( clname );
}

bool QgsRasterLayer::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: inOverview((bool)static_QUType_bool.get(_o+1)); break;
    case 1: popupTransparencySliderMoved((int)static_QUType_int.get(_o+1)); break;
    case 2: buildPyramids((RasterPyramidList)(*((RasterPyramidList*)static_QUType_ptr.get(_o+1)))); break;
    case 3: buildPyramids((RasterPyramidList)(*((RasterPyramidList*)static_QUType_ptr.get(_o+1))),(QString)static_QUType_QString.get(_o+2)); break;
    case 4: showLayerProperties(); break;
    case 5: populateHistogram((int)static_QUType_int.get(_o+1)); break;
    case 6: populateHistogram((int)static_QUType_int.get(_o+1),(int)static_QUType_int.get(_o+2)); break;
    case 7: populateHistogram((int)static_QUType_int.get(_o+1),(int)static_QUType_int.get(_o+2),(bool)static_QUType_bool.get(_o+3)); break;
    case 8: populateHistogram((int)static_QUType_int.get(_o+1),(int)static_QUType_int.get(_o+2),(bool)static_QUType_bool.get(_o+3),(bool)static_QUType_bool.get(_o+4)); break;
    case 9: static_QUType_ptr.set(_o,colorTable((int)static_QUType_int.get(_o+1))); break;
    default:
	return QgsMapLayer::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsRasterLayer::qt_emit( int _id, QUObject* _o )
{
    return QgsMapLayer::qt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES

bool QgsRasterLayer::qt_property( int id, int f, QVariant* v)
{
    return QgsMapLayer::qt_property( id, f, v);
}

bool QgsRasterLayer::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
